from LsBook.lsbook import main

if __name__ == '__main__':
    main(True)
